# Discovery and Integrations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovery-and-integrations#overview)
  * [Setting Up Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations#setting-up-out-of-the-box-integrations)
  * [Sync Logs of Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations#sync-logs-of-integrations)
  * [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations#discovery-and-integrations)
  * [Reference Catalog](https://help.sap.com/docs/leanix/ea/discovery-and-integrations#reference-catalog)


Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.
